@@ -23,7 +23,7 @@ async def execute_code_block(code: str, language: str, timeout: float = 1) -> Ru
     if language == 'python':
         process_args = ['python', '-c', code]
     elif language in ('shell', 'bash', 'sh'):
-        process_args = ['bash', '-c', code]
+        process_args = ['script', '-q', '-c', code]
     else:
         raise ValueError('Unknown language')
 
@@ -111,8 +111,8 @@ class Check:
                 expected = json.loads(expected)
                 actual = json.loads(actual)
             else:
-                expected = expected.strip()
-                actual = actual.strip()
+                expected = expected.strip().replace('\r\n', '\n')
+                actual = actual.strip().replace('\r\n', '\n')
             assert actual == expected, f"{self.code=} result does not match expected: {actual!r} != {expected!r}"
             print('OK')
         else:
